emit_success_fmt

Function emit_success_fmt 

pub fn emit_success_fmt(
    event: &str,
    fields: Value,
    human: Arguments<'_>,
    json: bool,
) -> Result<()>
Like emit_success, but the human line is built with format_args! (G-MAC-01).

Prefer this when the human text is dynamic and the JSON path does not need the formatted string (avoids allocating when json is true and when false).

Errors

Returns I/O errors from writing stdout (including BrokenPipe for JSON path).