pub fn load_primary_key() -> SshCliResult<(Option<PrimaryKey>, KeySource)>Expand description
Resolves primary key and source (does not auto-create).
Errors
Returns an error if a configured key source exists but cannot be read or parsed.
pub fn load_primary_key() -> SshCliResult<(Option<PrimaryKey>, KeySource)>Resolves primary key and source (does not auto-create).
Returns an error if a configured key source exists but cannot be read or parsed.