pub fn cancellation_flag() -> Arc<AtomicBool>Expand description
Returns the shared cancellation flag pointer.
Useful to pass the flag to async tasks that need
to check cancellation without calling is_cancelled directly.
pub fn cancellation_flag() -> Arc<AtomicBool>Returns the shared cancellation flag pointer.
Useful to pass the flag to async tasks that need
to check cancellation without calling is_cancelled directly.