pub fn is_interactive() -> boolExpand description
Returns true if the process is running in an interactive terminal (TTY).
Uses std::io::IsTerminal (stabilized in Rust 1.70) for detection
cross-platform without external dependencies.
pub fn is_interactive() -> boolReturns true if the process is running in an interactive terminal (TTY).
Uses std::io::IsTerminal (stabilized in Rust 1.70) for detection
cross-platform without external dependencies.