pub fn load(path: &PathBuf) -> SshCliResult<ConfigFile>Expand description
Loads the configuration file (returns empty if missing).
Errors
Returns an error if the file cannot be read or TOML/secret decryption fails.
pub fn load(path: &PathBuf) -> SshCliResult<ConfigFile>Loads the configuration file (returns empty if missing).
Returns an error if the file cannot be read or TOML/secret decryption fails.