pub fn use_json(json_local: bool, format: OutputFormat) -> boolExpand description
JSON efetivo a partir de flag local e format global (IO-001/002).
pub fn use_json(json_local: bool, format: OutputFormat) -> boolJSON efetivo a partir de flag local e format global (IO-001/002).