pub enum ScpAction {
Upload {
vps_name: String,
local: PathBuf,
remote: PathBuf,
password: Option<String>,
password_stdin: bool,
key: Option<String>,
key_passphrase: Option<String>,
key_passphrase_stdin: bool,
timeout: Option<u64>,
json: bool,
},
Download {
vps_name: String,
remote: PathBuf,
local: PathBuf,
password: Option<String>,
password_stdin: bool,
key: Option<String>,
key_passphrase: Option<String>,
key_passphrase_stdin: bool,
timeout: Option<u64>,
json: bool,
},
}Expand description
Actions of the scp subcommand (regular files only; no -r / no SFTP).
Variants
Upload
Uploads a local file to the remote host (regular files only).
Fields
Download
Downloads a remote file to the local host (regular files only).
Fields