pub enum SftpAction {
Upload {
all: bool,
hosts: Option<String>,
target: Vec<String>,
recursive: bool,
auth: SshAuthArgs,
timeout: Option<u64>,
json: bool,
},
Download {
all: bool,
hosts: Option<String>,
target: Vec<String>,
recursive: bool,
auth: SshAuthArgs,
timeout: Option<u64>,
json: bool,
},
Ls {
vps_name: String,
remote: String,
auth: SshAuthArgs,
timeout: Option<u64>,
json: bool,
},
Mkdir {
vps_name: String,
remote: String,
auth: SshAuthArgs,
timeout: Option<u64>,
json: bool,
},
Rmdir {
vps_name: String,
remote: String,
auth: SshAuthArgs,
timeout: Option<u64>,
json: bool,
},
Rm {
vps_name: String,
remote: String,
auth: SshAuthArgs,
timeout: Option<u64>,
json: bool,
},
Stat {
vps_name: String,
remote: String,
auth: SshAuthArgs,
timeout: Option<u64>,
json: bool,
},
Rename {
vps_name: String,
from: String,
to: String,
auth: SshAuthArgs,
timeout: Option<u64>,
json: bool,
},
}Expand description
Actions of the sftp subcommand (SFTP v3 subsystem).
Variants
Upload
Uploads a local file or tree to the remote host via SFTP.
Fields

target: Vec<String>Paths: VPS LOCAL REMOTE, multi-file VPS LOCAL... REMOTE_DIR, or fleet forms with --all/--hosts.

auth: SshAuthArgsSSH authentication overrides.
Download
Downloads a remote file or tree to the local host via SFTP.
Fields

auth: SshAuthArgsSSH authentication overrides.
Ls
Lists a remote directory.
Fields

auth: SshAuthArgsSSH authentication overrides.
Mkdir
Creates a remote directory.
Fields

auth: SshAuthArgsSSH authentication overrides.
Rmdir
Removes an empty remote directory.
Fields

auth: SshAuthArgsSSH authentication overrides.
Rm
Removes a remote file.
Fields

auth: SshAuthArgsSSH authentication overrides.
Stat
Shows metadata for a remote path.
Fields

auth: SshAuthArgsSSH authentication overrides.
Rename
Renames a remote path.