Module i18n

Module i18n 

ssh-cli internationalization system.

Provides bilingual Language with Message as the single source of UI strings. Locale detection is delegated to the locale module.

Language selection precedence:

  1. CLI --lang flag
  2. SSH_CLI_LANG environment variable
  3. System locale via sys_locale::get_locale()
  4. Fallback: Language::English

Enums

Language
Languages supported by the internationalization system.
Message
All system UI messages.

Functions

current_language
Returns the currently configured language.
initialize_language
Initializes i18n by detecting the OS locale.
t
Returns the message string in the current global language.