ssh-cli internationalization system.
Provides bilingual Language with Message as the single source of
UI strings. Locale detection is delegated to the locale module.
Language selection precedence:
- CLI
--langflag SSH_CLI_LANGenvironment variable- System locale via
sys_locale::get_locale() - Fallback:
Language::English
Enums
Functions
- current_
language - Returns the currently configured language.
- initialize_
language - Initializes i18n by detecting the OS locale.
- t
- Returns the message string in the current global language.