Module scp

Module scp 

File transfer via SCP over SSH (one-shot).

Wrapper around SshClient upload and download methods. Regular files only (no -r / no SFTP subsystem).

Structs

ScpOptions
Runtime overrides for the scp subcommand (parity with exec).

Functions

run_scp
Runs the SCP subcommand (upload/download).
run_scp_download_with_client
Testable SCP download that accepts the client as a parameter.
run_scp_upload_with_client
Testable SCP upload that accepts the client as a parameter.