File transfer via SCP over SSH (one-shot).
Wrapper around SshClient upload and download methods.
Regular files only (no -r / no SFTP subsystem).
Structs
- ScpOptions
- Runtime overrides for the
scpsubcommand (parity with exec).
Functions
- run_scp
- Runs the SCP subcommand (upload/download).
- run_
scp_ download_ with_ client - Testable SCP download that accepts the client as a parameter.
- run_
scp_ upload_ with_ client - Testable SCP upload that accepts the client as a parameter.