pub fn verify_tofu(
kh: &mut KnownHosts,
host: &str,
port: u16,
fingerprint: &str,
replace: bool,
) -> SshCliResult<bool>Expand description
Verifica fingerprint TOFU.
- Sem entrada: aceita e grava (TOFU).
- Com entrada igual: aceita.
- Com entrada diferente: recusa, a menos que
replaceseja true.
Errors
Returns an error if the host key changed and replacement was not allowed, or if persistence fails.